package com.ruoyi.project.task.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.project.task.mapper.TTaskInspectionMapper;
import com.ruoyi.project.task.domain.TTaskInspection;
import com.ruoyi.project.task.service.ITTaskInspectionService;

/**
 * 检测任务Service业务层处理
 *
 * @author ruoyi
 * @date 2022-11-21
 */
@Service
public class TTaskInspectionServiceImpl implements ITTaskInspectionService
{
    @Autowired
    private TTaskInspectionMapper tTaskInspectionMapper;

    /**
     * 查询检测任务
     *
     * @param id 检测任务主键
     * @return 检测任务
     */
    @Override
    public TTaskInspection selectTTaskInspectionById(Long id)
    {
        return tTaskInspectionMapper.selectTTaskInspectionById(id);
    }

    /**
     * 查询检测任务列表
     *
     * @param tTaskInspection 检测任务
     * @return 检测任务
     */
    @Override
    public List<TTaskInspection> selectTTaskInspectionList(TTaskInspection tTaskInspection)
    {
        return tTaskInspectionMapper.selectTTaskInspectionList(tTaskInspection);
    }

    /**
     * 新增检测任务
     *
     * @param tTaskInspection 检测任务
     * @return 结果
     */
    @Override
    public int insertTTaskInspection(TTaskInspection tTaskInspection)
    {
        return tTaskInspectionMapper.insertTTaskInspection(tTaskInspection);
    }

    /**
     * 修改检测任务
     *
     * @param tTaskInspection 检测任务
     * @return 结果
     */
    @Override
    public int updateTTaskInspection(TTaskInspection tTaskInspection)
    {
        return tTaskInspectionMapper.updateTTaskInspection(tTaskInspection);
    }

    /**
     * 批量删除检测任务
     *
     * @param ids 需要删除的检测任务主键
     * @return 结果
     */
    @Override
    public int deleteTTaskInspectionByIds(Long[] ids)
    {
        return tTaskInspectionMapper.deleteTTaskInspectionByIds(ids);
    }
    @Override
    public int updateTTaskInspectionByIds(Long[] ids)
    {
        return tTaskInspectionMapper.updateTTaskInspectionByIds(ids);
    }

    /**
     * 删除检测任务信息
     *
     * @param id 检测任务主键
     * @return 结果
     */
    @Override
    public int deleteTTaskInspectionById(Long id)
    {
        return tTaskInspectionMapper.deleteTTaskInspectionById(id);
    }
}
